@@ -1,8 +1,9 @@
 import json
 import os
 import jsonschema
-from ref_Resolver import ExtendedRefResolver
-from configs import mappingObject
+from .ref_Resolver import ExtendedRefResolver
+from .configs import mappingObject
+from pkg_resources import resource_filename
 
 
 def executeValidateJson(data, schema):
@@ -11,7 +12,7 @@ def executeValidateJson(data, schema):
             data,
             schema,
             resolver=ExtendedRefResolver(
-                base_uri=f"{os.path.abspath(os.curdir)}/Schema",
+                base_uri=f"{os.path.abspath(os.curdir)}/graas_utilities/Schema",
                 referrer=schema,
             ),
         )
@@ -24,7 +25,7 @@ def executeValidateJson(data, schema):
 
 
 def extract_data_from_file(schema_file):
-    path_for_schema = f"{os.path.abspath(os.curdir)}/Schema"
+    path_for_schema = resource_filename(__name__, '/Schema')
 
     with open(f"{path_for_schema}/{schema_file}.json", "r") as schema_file:
         schemaObj = json.load(schema_file)
@@ -52,7 +53,8 @@ def validateJson(dataJsonString, reportType):
             }
         if jsonObject:
             schemaObject = extract_data_from_file(schema_file)
-            return executeValidateJson(jsonObject, schemaObject)
+            isValidated = executeValidateJson(jsonObject, schemaObject)
+            return isValidated
         else:
             return {
                 "status": "SCHEMA_VALIDATION_FAILED",
